#include <wxnc/color.hpp>
#include <wxnc/menu.hpp>
#include <wxnc/menubar.hpp>
#include <wxnc/statictext.hpp>
#include <wxnc/statusbar.hpp>
#include <wxnc/window.hpp>
#include <wx/defs.h>
#include <wx/gdicmn.h>
#include <wx/string.h>
#include <ncurses.h>
#include "internal.h"

wxncMenu::wxncMenu(const wxString &title, long style) :
	wxncWindow(NULL, wxID_ANY, wxDefaultPosition, wxDefaultSize,
		style | wxBORDER_NONE)
{
	m_fgcolor.SetInvert(true);
	m_bgcolor.SetInvert(true);
	m_title = new wxncStaticText(this, wxID_ANY, title);
}

wxncMenu::~wxncMenu(void)
{
}

wxString wxncMenu::GetTitle(void) const
{
	return m_title->GetLabel();
}

void wxncMenu::SetTitle(const wxString &title)
{
	m_title->SetLabel(title);
}

void wxncMenu::RecalcSizes(void)
{
	m_title->RecalcSizes();
	m_minsize = m_title->GetMinSize();
	m_minsize.IncBy(2, 0);
}

void wxncMenu::Layout(void)
{
	m_title->SetPosition(m_pos.x + 1, m_pos.y);
	m_title->SetSize(m_title->GetMinSize());
	m_title->Layout();
}

void wxncMenu::Update(void)
{
	wxncWindow::Update();
	m_title->Update();
}

wxncMenuBar::wxncMenuBar(long style) :
	wxncWindow(NULL, wxID_ANY, wxDefaultPosition, wxDefaultSize,
		style | wxBORDER_NONE)
{
}

wxncMenuBar::~wxncMenuBar(void)
{
	for (std::list<wxncMenu *>::iterator i = menu_list.begin();
	     i != menu_list.end(); ++i)
		delete *i;
}

bool wxncMenuBar::Append(wxncMenu *menu, const wxString &title)
{
	menu->SetTitle(title);
	menu_list.push_back(menu);
	return true;
}

void wxncMenuBar::RecalcSizes(void)
{
	m_minsize = wxSize(0, 1);

	for (std::list<wxncMenu *>::const_iterator m = menu_list.begin();
	     m != menu_list.end(); ++m)
	{
		(*m)->RecalcSizes();
		m_minsize.IncBy((*m)->GetMinWidth(), 0);
	}
}

void wxncMenuBar::Layout(void)
{
	wxSize s;
	int px = m_pos.x;

	for (std::list<wxncMenu *>::const_iterator m = menu_list.begin();
	     m != menu_list.end(); ++m)
	{
		(*m)->SetPosition(px, m_pos.y);
		s = (*m)->GetMinSize();
		(*m)->SetSize(s);
		(*m)->Layout();
		px += s.x;
	}
}

void wxncMenuBar::Update(void)
{
	wxncWindow::Update();
	for (std::list<wxncMenu *>::const_iterator m = menu_list.begin();
	     m != menu_list.end(); ++m)
		(*m)->Update();
}

void wxncMenuBar::render_background(int sx, int sy, int ex, int ey)
{
	if (has_colors())
		wxncWindow::render_background(sx, sy, ex, ey);
	else
		wxnc_clear_area(sx, sy, ex, ey, A_REVERSE);
}

wxncStatusBar::wxncStatusBar(wxncWindow *parent, wxWindowID id, long style,
    const wxString &foo) :
	wxncWindow(NULL, id, wxDefaultPosition, wxDefaultSize,
		style | wxBORDER_NONE)
{
	m_fgcolor.SetInvert(true);
	m_bgcolor.SetInvert(true);
	m_sizegrip = style & wxST_SIZEGRIP;
}

wxncStatusBar::~wxncStatusBar(void)
{
}

void wxncStatusBar::SetFieldsCount(unsigned int, const int *)
{
}

void wxncStatusBar::SetStatusText(const wxString &label, int)
{
	m_text = label;
}

void wxncStatusBar::Update(void)
{
	wxncWindow::Update();
	attrset(wxncColor::GetColor(m_fgcolor, m_bgcolor));
	mvaddstr(m_pos.y, m_pos.x, m_text.ToUTF8());
	if (m_sizegrip) {
		/* Use edge- color */
		attrset(wxncColor::GetColor(wxncColor::
			b_coherence_map[m_bgcolor.nc_index()][1], m_bgcolor));
		mvaddch(m_pos.y, m_pos.x + m_size.x - 1, '/');
	}
}
