#include <wxnc/button.hpp>
#include <wxnc/checkbox.hpp>
#include <wxnc/statictext.hpp>
#include <wx/defs.h>
#include <ncurses.h>
#include "internal.h"

wxncButton::wxncButton(wxncWindow *parent, wxWindowID id,
    const wxString &label, const wxPoint &pos, const wxSize &size,
    long style) :
	wxncWindow(parent, id, pos, size, style)
{
	m_label = new wxncStaticText(this, wxID_ANY, label);
}

void wxncButton::RecalcSizes(void)
{
	m_label->RecalcSizes();
	m_minsize = m_label->GetMinSize();
	m_minsize.IncBy(2, 0);
	wxncWindow::recalc_sizes_bh();
}

void wxncButton::Layout(void)
{
	m_label->SetPosition(m_pos.x + 2, m_pos.y + 1);
	m_label->Layout();
}

void wxncButton::Update(void)
{
	wxncWindow::Update();
	m_label->Update();
}

wxncCheckBox::wxncCheckBox(wxncWindow *parent, wxWindowID id,
    const wxString &label, const wxPoint &pos, const wxSize &size,
    long style) :
	wxncWindow(parent, id, pos, size, style | wxBORDER_NONE)
{
	m_label = new wxncStaticText(this, wxID_ANY, label);
}

wxncCheckBox::~wxncCheckBox(void)
{
}

void wxncCheckBox::SetValue(bool x)
{
	m_enabled = x;
}

void wxncCheckBox::RecalcSizes(void)
{
	m_label->RecalcSizes();
	m_minsize = m_label->GetMinSize();
	m_minsize.IncBy(4, 0);
	wxncWindow::recalc_sizes_bh();
}

void wxncCheckBox::Layout(void)
{
	m_label->SetPosition(m_pos.x + 4, m_pos.y);
	m_label->Layout();
}

void wxncCheckBox::Update(void)
{
	m_label->Update();
	attrset(wxncColor::GetColor(m_fgcolor, m_bgcolor));
	if (m_enabled)
		mvaddstr(m_pos.y, m_pos.x, "[*] ");
	else
		mvaddstr(m_pos.y, m_pos.x, "[ ] ");
}

wxncStaticText::wxncStaticText(wxncWindow *parent, wxWindowID id,
    const wxString &label, const wxPoint &pos, const wxSize &size,
    long style, const wxString &name) :
	wxncWindow(parent, id, pos, size, style | wxBORDER_NONE)
{
	m_label = label;
}

wxString wxncStaticText::GetLabel(void) const
{
	return m_label;
}

void wxncStaticText::SetLabel(const wxString &label)
{
	m_label = label;
}

void wxncStaticText::RecalcSizes(void)
{
	m_minsize = wxSize(m_label.Length(), 1);
}

void wxncStaticText::Update(void)
{
	attrset(wxncColor::GetColor(m_fgcolor, m_bgcolor));
	mvaddstr(m_pos.y, m_pos.x, m_label.ToUTF8());
}
